@@ -1,27 +1,39 @@
 #!/usr/bin/env python3
 import typing
-from sys import argv
+import sys
 from os import environ
 from json import loads
 from subprocess import Popen, CalledProcessError
 
 
+def error_shortener(error_type, value, traceback):
+    print(error_type.__name__ + ": " + str(value))
+
+
 class CommonHarnessLib:
 
-    def __init__(self, enable_s3: bool = True, ignore_json_args: bool = False):
+    def __init__(
+            self,
+            enable_s3: bool = True,
+            ignore_json_args: bool = False,
+            shorten_errors: bool = True
+         ):
         # Get JSON parameters from harness
         if not ignore_json_args:
             self.get_json_args()
         # Deal with s3 initialization
         if enable_s3:
             self.init_s3()
+        # Hide error traceback
+        if shorten_errors:
+            sys.excepthook = error_shortener
 
     """
         Parse JSON from argv[1], which is standard harness input format
     """
     def get_json_args(self):
         try:
-            self.json_args = loads(argv[1])
+            self.json_args = loads(sys.argv[1])
         except IndexError:
             raise ValueError("Harness JSON args not given.")
         except ValueError:
